@@ -4,32 +4,17 @@
 #' time series. It uses a Sakoe-Chiba constraint.
 #'
 #' @export
+#' @include lb-improved.R
 #'
 #' @inheritParams lb_improved
-#'
-#' @details
-#'
-#' The reference time series should go in `x`, whereas the query time series should go in `y`.
-#'
-#' @template window
+#' @inherit lb_improved details
+#' @inheritSection lb_improved Note
 #'
 #' @return A list with:
 #'
 #'   - `d`: The lower bound of the DTW distance.
-#'   - `upper.env`: The time series of `y`'s upper envelop.
-#'   - `lower.env`: The time series of `y`'s lower envelop.
-#'
-#' @note
-#'
-#' The lower bound is defined for time series of equal length only and is **not** symmetric.
-#'
-#' If you wish to calculate the lower bound between several time series, it would be better to use
-#' the version registered with the `proxy` package, since it includes some small optimizations. The
-#' convention mentioned above for references and queries still holds. See the examples.
-#'
-#' The proxy version of `force.symmetry` should only be used when only `x` is provided or both `x`
-#' and `y` are identical. It compares the lower and upper triangular of the resulting distance
-#' matrix and forces symmetry in such a way that the tightest lower bound is obtained.
+#'   - `upper.env`: The time series of `y`'s upper envelope.
+#'   - `lower.env`: The time series of `y`'s lower envelope.
 #'
 #' @references
 #'
@@ -67,57 +52,31 @@ lb_keogh <- function(x, y, window.size = NULL, norm = "L1",
                      force.symmetry = FALSE, error.check = TRUE)
 {
     norm <- match.arg(norm, c("L1", "L2"))
-
     if (error.check) check_consistency(x, "ts")
-
-    if (is_multivariate(list(x)))
-        stop("lb_keogh does not support multivariate series.")
+    if (is_multivariate(list(x))) stop("lb_keogh does not support multivariate series.")
 
     if (is.null(lower.env) || is.null(upper.env)) {
+        if (is_multivariate(list(y))) stop("lb_keogh does not support multivariate series.")
+        if (length(x) != length(y)) stop("The series must have the same length")
         if (error.check) check_consistency(y, "ts")
-
-        if (is_multivariate(list(y)))
-            stop("lb_keogh does not support multivariate series.")
-
-        if (length(x) != length(y))
-            stop("The series must have the same length")
-
         window.size <- check_consistency(window.size, "window")
-    }
 
-    ## NOTE: the 'window.size' definition varies betwen dtw/call_envelop and runmin/max
-    if (is.null(lower.env) && is.null(upper.env)) {
-        envelopes <- compute_envelop(y, window.size = window.size, error.check = FALSE)
+        envelopes <- compute_envelope(y, window.size = window.size, error.check = FALSE)
         lower.env <- envelopes$lower
         upper.env <- envelopes$upper
 
-    } else if (is.null(lower.env)) {
-        lower.env <- caTools::runmin(y, window.size*2L + 1L)
-
-    } else if (is.null(upper.env)) {
-        upper.env <- caTools::runmax(y, window.size*2L + 1L)
+    } else {
+        if (length(lower.env) != length(x))
+            stop("Length mismatch between 'x' and the lower envelope")
+        if (length(upper.env) != length(x))
+            stop("Length mismatch between 'x' and the upper envelope")
     }
 
-    if (length(lower.env) != length(x))
-        stop("Length mismatch between 'x' and the lower envelop")
-
-    if (length(upper.env) != length(x))
-        stop("Length mismatch between 'x' and the upper envelop")
-
-    D <- rep(0, length(x))
-
-    ind1 <- x > upper.env
-    D[ind1] <- x[ind1] - upper.env[ind1]
-    ind2 <- x < lower.env
-    D[ind2] <- lower.env[ind2] - x[ind2]
-
-    d <- switch(EXPR = norm,
-                L1 = sum(D),
-                L2 = sqrt(sum(D^2)))
+    p <- switch(norm, L1 = 1L, L2 = 2L)
+    d <- .Call(C_lbk, x, p, lower.env, upper.env, PACKAGE = "dtwclust")
 
     if (force.symmetry) {
-        d2 <- lb_keogh(x = y, y = x, window.size = window.size, norm = norm)
-
+        d2 <- lb_keogh(x = y, y = x, window.size = window.size, norm = norm, error.check = FALSE)
         if (d2$d > d) {
             d <- d2$d
             lower.env = d2$lower.env
@@ -125,54 +84,44 @@ lb_keogh <- function(x, y, window.size = NULL, norm = "L1",
         }
     }
 
-    ## Finish
-    list(d = d,
-         upper.env = upper.env,
-         lower.env = lower.env)
+    ## return
+    list(d = d, upper.env = upper.env, lower.env = lower.env)
 }
 
-# ========================================================================================================
-# Loop without using native 'proxy' looping (to avoid multiple calculations of the envelop)
-# ========================================================================================================
+# ==================================================================================================
+# Loop without using native 'proxy' looping (to avoid multiple calculations of the envelope)
+# ==================================================================================================
 
 lb_keogh_proxy <- function(x, y = NULL, window.size = NULL, norm = "L1", ...,
                            force.symmetry = FALSE, pairwise = FALSE, error.check = TRUE)
 {
     norm <- match.arg(norm, c("L1", "L2"))
-
     window.size <- check_consistency(window.size, "window")
-
     x <- any2list(x)
-
-    if (error.check)
-        check_consistency(x, "tslist")
+    if (error.check) check_consistency(x, "tslist")
 
     if (is.null(y)) {
         y <- x
 
     } else {
         y <- any2list(y)
-
         if (error.check) check_consistency(y, "tslist")
     }
 
     if (is_multivariate(x) || is_multivariate(y))
         stop("lb_keogh does not support multivariate series.")
 
-    retclass <- "crossdist"
-
-    envelops <- lapply(y, function(s) { compute_envelop(s, window.size, error.check = FALSE) })
-
-    lower.env <- lapply(envelops, "[[", "lower")
-    upper.env <- lapply(envelops, "[[", "upper")
-
+    envelopes <- lapply(y, function(s) { compute_envelope(s, window.size, error.check = FALSE) })
+    lower.env <- lapply(envelopes, "[[", "lower")
+    upper.env <- lapply(envelopes, "[[", "upper")
     lower.env <- split_parallel(lower.env)
     upper.env <- split_parallel(upper.env)
 
+
     if (pairwise) {
         X <- split_parallel(x)
-
         validate_pairwise(X, lower.env)
+        retclass <- "pairdist"
 
         D <- foreach(x = X, lower.env = lower.env, upper.env = upper.env,
                      .packages = "dtwclust",
@@ -188,30 +137,29 @@ lb_keogh_proxy <- function(x, y = NULL, window.size = NULL, norm = "L1", ...,
                                 })
                      }
 
-        retclass <- "pairdist"
-
     } else {
+        retclass <- "crossdist"
+
         D <- foreach(lower.env = lower.env, upper.env = upper.env,
                      .packages = "dtwclust",
                      .combine = cbind,
                      .multicombine = TRUE) %op% {
-                         ret <- mapply(U = upper.env, L = lower.env,
-                                       MoreArgs = list(x = x),
-                                       SIMPLIFY = FALSE,
-                                       FUN = function(U, L, x) {
-                                           ## This will return one column of the distance matrix
-                                           D <- sapply(x, u = U, l = L,
-                                                       FUN = function(x, u, l) {
-                                                           lb_keogh(x,
-                                                                    norm = norm,
-                                                                    lower.env = l,
-                                                                    upper.env = u,
-                                                                    error.check = FALSE)$d
-                                                       })
-                                           D
-                                       })
+                         d <- mapply(U = upper.env, L = lower.env,
+                                     MoreArgs = list(x = x),
+                                     SIMPLIFY = FALSE,
+                                     FUN = function(U, L, x) {
+                                         ## This will return one column of the distance matrix
+                                         sapply(x, u = U, l = L,
+                                                FUN = function(x, u, l) {
+                                                    lb_keogh(x,
+                                                             norm = norm,
+                                                             lower.env = l,
+                                                             upper.env = u,
+                                                             error.check = FALSE)$d
+                                                })
+                                     })
 
-                         do.call(cbind, ret)
+                         do.call(cbind, d)
                      }
     }
 
@@ -220,20 +168,19 @@ lb_keogh_proxy <- function(x, y = NULL, window.size = NULL, norm = "L1", ...,
             warning("Unable to force symmetry. Resulting distance matrix is not square.")
 
         } else {
-            ind.tri <- lower.tri(D)
-
-            new.low.tri.vals <- t(D)[ind.tri]
-            indCorrect <- D[ind.tri] > new.low.tri.vals
-            new.low.tri.vals[indCorrect] <- D[ind.tri][indCorrect]
-
-            D[ind.tri] <- new.low.tri.vals
+            ind_tri <- lower.tri(D)
+            new_low_tri_vals <- t(D)[ind_tri]
+            ind_correct <- D[ind_tri] > new_low_tri_vals
+            new_low_tri_vals[ind_correct] <- D[ind_tri][ind_correct]
+            D[ind_tri] <- new_low_tri_vals
             D <- t(D)
-            D[ind.tri] <- new.low.tri.vals
+            D[ind_tri] <- new_low_tri_vals
         }
     }
 
     class(D) <- retclass
     attr(D, "method") <- "LB_Keogh"
 
+    ## return
     D
 }
