@@ -1,10 +1,11 @@
 #include <stdlib.h>
 #include <R.h>
 #include <Rinternals.h>
+#include "dtwclust.h"
 
-/* ==================================================================================================================================================
+/* =================================================================================================
  * All possible combinations in pairs
- * ==================================================================================================================================================
+ * =================================================================================================
  */
 
 void pairs_c(const int n, const int nrow, int *out, const int lower)
