@@ -76,7 +76,8 @@ test_that("Operations with dtwclustFamily@dist and lbk give expected results", {
                  tolerance = 0, check.attributes = FALSE)
 
     ## ---------------------------------------------------------- tsclustFamily, with distmat
-    ts_ctrl$distmat <- distmat
+    ts_ctrl$distmat <- dtwclust:::Distmat$new(distmat = distmat,
+                                              id_cent = attr(centroids, "id_cent"))
 
     family <- new("tsclustFamily",
                   control = ts_ctrl,
@@ -93,6 +94,28 @@ test_that("Operations with dtwclustFamily@dist and lbk give expected results", {
 
     ## ---------------------------------------------------------- ref
     assign("distmat_lbk", whole_distmat, persistent)
+
+    ## ---------------------------------------------------------- tsclustFamily, sparse distmat
+    ts_ctrl$symmetric <- FALSE
+    dm <- dtwclust:::SparseDistmat$new(series = x,
+                                       control = ts_ctrl,
+                                       distance = "lbk",
+                                       dist_args = list(window.size = ctrl@window.size),
+                                       id_cent = attr(centroids, "id_cent"))
+    ts_ctrl$distmat <- dm
+
+    family <- new("tsclustFamily",
+                  control = ts_ctrl,
+                  dist = "lbk")
+
+    sub_distmat <- base::as.matrix(family@dist(x, centroids))
+    whole_distmat <- base::as.matrix(family@dist(x))
+
+    expect_equal(whole_distmat, base::as.matrix(distmat), info = "Whole, sparse distmat",
+                 tolerance = 0, check.attributes = FALSE)
+
+    expect_equal(sub_distmat, base::as.matrix(distmat[ , c(1L, 15L), drop = FALSE]),
+                 info = "Sub, sparse distmat", tolerance = 0, check.attributes = FALSE)
 })
 
 # ==================================================================================================
@@ -158,7 +181,8 @@ test_that("Operations with dtwclustFamily@dist and lbi give expected results", {
                  tolerance = 0, check.attributes = FALSE)
 
     ## ---------------------------------------------------------- tsclustFamily, with distmat
-    ts_ctrl$distmat <- distmat
+    ts_ctrl$distmat <- dtwclust:::Distmat$new(distmat = distmat,
+                                              id_cent = attr(centroids, "id_cent"))
 
     family <- new("tsclustFamily",
                   control = ts_ctrl,
@@ -175,6 +199,28 @@ test_that("Operations with dtwclustFamily@dist and lbi give expected results", {
 
     ## ---------------------------------------------------------- ref
     assign("distmat_lbi", whole_distmat, persistent)
+
+    ## ---------------------------------------------------------- tsclustFamily, sparse distmat
+    ts_ctrl$symmetric <- FALSE
+    dm <- dtwclust:::SparseDistmat$new(series = x,
+                                       control = ts_ctrl,
+                                       distance = "lbi",
+                                       dist_args = list(window.size = ctrl@window.size),
+                                       id_cent = attr(centroids, "id_cent"))
+    ts_ctrl$distmat <- dm
+
+    family <- new("tsclustFamily",
+                  control = ts_ctrl,
+                  dist = "lbi")
+
+    sub_distmat <- base::as.matrix(family@dist(x, centroids))
+    whole_distmat <- base::as.matrix(family@dist(x))
+
+    expect_equal(whole_distmat, base::as.matrix(distmat), info = "Whole, sparse distmat",
+                 tolerance = 0, check.attributes = FALSE)
+
+    expect_equal(sub_distmat, base::as.matrix(distmat[ , c(1L, 15L), drop = FALSE]),
+                 info = "Sub, sparse distmat", tolerance = 0, check.attributes = FALSE)
 })
 
 # ==================================================================================================
@@ -240,7 +286,8 @@ test_that("Operations with dtwclustFamily@dist and sbd give expected results", {
                  tolerance = 0, check.attributes = FALSE)
 
     ## ---------------------------------------------------------- tsclustFamily, with distmat
-    ts_ctrl$distmat <- distmat
+    ts_ctrl$distmat <- dtwclust:::Distmat$new(distmat = distmat,
+                                              id_cent = attr(centroids, "id_cent"))
 
     family <- new("tsclustFamily",
                   control = ts_ctrl,
@@ -257,6 +304,28 @@ test_that("Operations with dtwclustFamily@dist and sbd give expected results", {
 
     ## ---------------------------------------------------------- ref
     assign("distmat_sbd", whole_distmat, persistent)
+
+    ## ---------------------------------------------------------- tsclustFamily, sparse distmat
+    ts_ctrl$symmetric <- TRUE
+    dm <- dtwclust:::SparseDistmat$new(series = x,
+                                       control = ts_ctrl,
+                                       distance = "sbd",
+                                       dist_args = list(),
+                                       id_cent = attr(centroids, "id_cent"))
+    ts_ctrl$distmat <- dm
+
+    family <- new("tsclustFamily",
+                  control = ts_ctrl,
+                  dist = "sbd")
+
+    sub_distmat <- base::as.matrix(family@dist(x, centroids))
+    whole_distmat <- base::as.matrix(family@dist(x))
+
+    expect_equal(whole_distmat, base::as.matrix(distmat), info = "Whole, sparse distmat",
+                 check.attributes = FALSE)
+
+    expect_equal(sub_distmat, base::as.matrix(distmat[ , c(1L, 15L), drop = FALSE]),
+                 info = "Sub, sparse distmat", check.attributes = FALSE)
 })
 
 # ==================================================================================================
@@ -319,7 +388,8 @@ test_that("Operations with dtwclustFamily@dist and dtw_lb give expected results"
                  tolerance = 0, check.attributes = FALSE)
 
     ## ---------------------------------------------------------- tsclustFamily, with distmat
-    ts_ctrl$distmat <- distmat
+    ts_ctrl$distmat <- dtwclust:::Distmat$new(distmat = distmat,
+                                              id_cent = attr(centroids, "id_cent"))
 
     family <- new("tsclustFamily",
                   control = ts_ctrl,
@@ -403,7 +473,8 @@ test_that("Operations with dtwclustFamily@dist and dtw give expected results", {
                  tolerance = 0, check.attributes = FALSE)
 
     ## ---------------------------------------------------------- tsclustFamily, with distmat
-    ts_ctrl$distmat <- distmat
+    ts_ctrl$distmat <- dtwclust:::Distmat$new(distmat = distmat,
+                                              id_cent = attr(centroids, "id_cent"))
 
     family <- new("tsclustFamily",
                   control = ts_ctrl,
@@ -487,7 +558,8 @@ test_that("Operations with dtwclustFamily@dist and dtw2 give expected results",
                  tolerance = 0, check.attributes = FALSE)
 
     ## ---------------------------------------------------------- tsclustFamily, with distmat
-    ts_ctrl$distmat <- distmat
+    ts_ctrl$distmat <- dtwclust:::Distmat$new(distmat = distmat,
+                                              id_cent = attr(centroids, "id_cent"))
 
     family <- new("tsclustFamily",
                   control = ts_ctrl,
@@ -569,7 +641,8 @@ test_that("Operations with dtwclustFamily@dist and dtw_basic give expected resul
                  tolerance = 0, check.attributes = FALSE)
 
     ## ---------------------------------------------------------- tsclustFamily, with distmat
-    ts_ctrl$distmat <- distmat
+    ts_ctrl$distmat <- dtwclust:::Distmat$new(distmat = distmat,
+                                              id_cent = attr(centroids, "id_cent"))
 
     family <- new("tsclustFamily",
                   control = ts_ctrl,
@@ -586,6 +659,28 @@ test_that("Operations with dtwclustFamily@dist and dtw_basic give expected resul
 
     ## ---------------------------------------------------------- ref
     assign("distmat_dtwb", whole_distmat, persistent)
+
+    ## ---------------------------------------------------------- tsclustFamily, sparse distmat
+    ts_ctrl$symmetric <- FALSE
+    dm <- dtwclust:::SparseDistmat$new(series = x,
+                                       control = ts_ctrl,
+                                       distance = "dtw_basic",
+                                       dist_args = list(window.size = ctrl@window.size),
+                                       id_cent = attr(centroids, "id_cent"))
+    ts_ctrl$distmat <- dm
+
+    family <- new("tsclustFamily",
+                  control = ts_ctrl,
+                  dist = "dtw_basic")
+
+    sub_distmat <- base::as.matrix(family@dist(x, centroids))
+    whole_distmat <- base::as.matrix(family@dist(x))
+
+    expect_equal(whole_distmat, base::as.matrix(distmat), info = "Whole, sparse distmat",
+                 tolerance = 0, check.attributes = FALSE)
+
+    expect_equal(sub_distmat, base::as.matrix(distmat[ , c(1L, 15L), drop = FALSE]),
+                 info = "Sub, sparse distmat", tolerance = 0, check.attributes = FALSE)
 })
 
 # ==================================================================================================
@@ -653,7 +748,8 @@ test_that("Operations with dtwclustFamily@dist and gak give expected results", {
                  tolerance = 0, check.attributes = FALSE)
 
     ## ---------------------------------------------------------- tsclustFamily, with distmat
-    ts_ctrl$distmat <- distmat
+    ts_ctrl$distmat <- dtwclust:::Distmat$new(distmat = distmat,
+                                              id_cent = attr(centroids, "id_cent"))
 
     family <- new("tsclustFamily",
                   control = ts_ctrl,
@@ -670,6 +766,29 @@ test_that("Operations with dtwclustFamily@dist and gak give expected results", {
 
     ## ---------------------------------------------------------- ref
     assign("distmat_gak", whole_distmat, persistent)
+
+    ## ---------------------------------------------------------- tsclustFamily, sparse distmat
+    ts_ctrl$symmetric <- FALSE
+    dm <- dtwclust:::SparseDistmat$new(series = x,
+                                       control = ts_ctrl,
+                                       distance = "gak",
+                                       dist_args = list(window.size = ctrl@window.size,
+                                                        sigma = 100),
+                                       id_cent = attr(centroids, "id_cent"))
+    ts_ctrl$distmat <- dm
+
+    family <- new("tsclustFamily",
+                  control = ts_ctrl,
+                  dist = "gak")
+
+    sub_distmat <- base::as.matrix(family@dist(x, centroids))
+    whole_distmat <- base::as.matrix(family@dist(x))
+
+    expect_equal(whole_distmat, base::as.matrix(distmat), info = "Whole, sparse distmat",
+                 tolerance = 0, check.attributes = FALSE)
+
+    expect_equal(sub_distmat, base::as.matrix(distmat[ , c(1L, 15L), drop = FALSE]),
+                 info = "Sub, sparse distmat", tolerance = 0, check.attributes = FALSE)
 })
 
 # =================================================================================================
